==> haskell-missingh-1.6.0.1-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MissingH
version:              1.6.0.1
visibility:           public
id:                   MissingH-1.6.0.1-1Tc63iartmyIk3xkhFTJh6
key:                  MissingH-1.6.0.1-1Tc63iartmyIk3xkhFTJh6
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  f7e660050c18204b275c094446d6939b
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/MissingH-1.6.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/MissingH-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.1-1Tc63iartmyIk3xkhFTJh6
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 hslogger-1.3.1.0-JA7JjXWPMIh8W5uwd9q0lr mtl-2.2.2
    network-3.1.4.0-23ur646Pq0yGXZtPd0ysVN
    network-bsd-2.8.1.0-EhWcQumb3OP77NVFI8ylIE
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh
    old-time-1.1.0.3-B4Ro2AUl5kn1VzPHPQkaoe parsec-3.1.14.0
    process-1.6.13.2 regex-compat-0.95.2.1-itFB4fXPjn9OuocZGgbix
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-missingh-1.6.0.1-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-missingh.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 MissingH
version:              1.6.0.1
visibility:           public
id:                   MissingH-1.6.0.1-DpYVxUtYh78JL8Ig4ZQp8p
key:                  MissingH-1.6.0.1-DpYVxUtYh78JL8Ig4ZQp8p
license:              BSD-3-Clause
copyright:            Copyright (c) 2004-2018 John Goerzen
maintainer:           Andreas Abel
author:               John Goerzen
synopsis:             Large utility library
description:
    @MissingH@ is a library of all sorts of utility functions for Haskell
    programmers.  It is written in pure Haskell and thus should be
    extremely portable and easy to use.

category:             Unclassified
abi:                  963fbbb8b38fd40bab8f8dcb1e0e43c5
exposed:              True
exposed-modules:
    Control.Concurrent.Thread.Utils Data.BinPacking Data.Bits.Utils
    Data.CSV Data.Compression.Inflate Data.Either.Utils
    Data.Hash.CRC32.GZip Data.Hash.MD5 Data.Hash.MD5.Zord64_HARD
    Data.List.Utils Data.MIME.Types Data.Map.Utils Data.Maybe.Utils
    Data.Progress.Meter Data.Progress.Tracker Data.Quantity
    Data.String.Utils Data.Tuple.Utils Network.Email.Mailbox
    Network.Email.Sendmail Network.SocketServer Network.Utils
    System.Cmd.Utils System.Console.GetOpt.Utils System.Daemon
    System.Debian System.Debian.ControlParser System.FileArchive.GZip
    System.IO.Binary System.IO.HVFS System.IO.HVFS.Combinators
    System.IO.HVFS.InstanceHelpers System.IO.HVFS.Utils System.IO.HVIO
    System.IO.PlafCompat System.IO.StatCompat System.IO.Utils
    System.IO.WindowsCompat System.Path System.Path.Glob
    System.Path.NameManip System.Path.WildMatch System.Posix.Consts
    System.Time.Utils Text.ParserCombinators.Parsec.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/MissingH-1.6.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/MissingH-1.6.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-missingh
hs-libraries:         HSMissingH-1.6.0.1-DpYVxUtYh78JL8Ig4ZQp8p
depends:
    array-0.5.4.0 base-4.15.1.0 containers-0.6.4.1 directory-1.3.6.2
    filepath-1.4.2.1 hslogger-1.3.1.0-68cva3tAUC714cLtvaO2Va mtl-2.2.2
    network-3.1.4.0-9Bfooq2NUZQBZiFYQuYMVQ
    network-bsd-2.8.1.0-9bz2N6BapwjHqF4x5BARTY
    old-locale-1.0.0.7-B94o3sNLYrV8oE3WO2rqHh
    old-time-1.1.0.3-B4Ro2AUl5kn1VzPHPQkaoe parsec-3.1.14.0
    process-1.6.13.2 regex-compat-0.95.2.1-itFB4fXPjn9OuocZGgbix
    time-1.9.3 unix-2.7.2.2

haddock-interfaces:   /usr/share/doc/haskell-missingh/html/MissingH.haddock
haddock-html:         /usr/share/doc/haskell-missingh/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
